<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Strings for component 'block_tag_youtube', language 'id', version '5.0'.
 *
 * @package     block_tag_youtube
 * @category    string
 * @copyright   1999 Martin Dougiamas and contributors
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */

defined('MOODLE_INTERNAL') || die();

$string['anycategory'] = 'Setiap kategori';
$string['apierror'] = 'Kunci API YouTube tidak disetel. Hubungi administrator Anda.';
$string['apikey'] = 'Kunci API';
$string['apikeyinfo'] = 'Dapatkan <a href="https://developers.google.com/youtube/v3/getting-started">kunci API Google</a> untuk situs Moodle Anda.';
$string['autosvehicles'] = 'Mobil & Kendaraan';
$string['category'] = 'Kategori';
$string['categoryerror'] = 'Gagal mendapatkan daftar kategori. <br> {$a}';
$string['comedy'] = 'Komedi';
$string['configtitle'] = 'Judul blok YouTube';
$string['education'] = 'Edukasi';
$string['entertainment'] = 'Hiburan';
$string['filmsanimation'] = 'Film & Animasi';
$string['gadgetsgames'] = 'Gadget dan Gim';
$string['howtodiy'] = 'How-to & DIY';
$string['includeonlyvideosfromplaylist'] = 'Sertakan hanya video dari daftar putar dengan id';
$string['music'] = 'Musik';
$string['newspolitics'] = 'Berita & Politik';
$string['nonprofitactivism'] = 'Nirlaba & Aktivisme';
$string['numberofvideos'] = 'Jumlah video';
$string['peopleblogs'] = 'Orang & Blog';
$string['petsanimals'] = 'Peliharaan & Hewan';
$string['pluginname'] = 'YouTube';
$string['privacy:metadata'] = 'Blok YouTube hanya menampilkan data yang disimpan di lokasi lain.';
$string['requesterror'] = 'Data tidak dapat diperoleh dari server. Hubungi administrator Anda jika masalah berlanjut.';
$string['scienceandtech'] = 'Sains dan Teknologi';
$string['sports'] = 'Olahraga';
$string['tag_youtube:addinstance'] = 'Tambahkan blok YouTube';
$string['travel'] = 'Perjalanan & Tempat';
